@@ -31,6 +31,12 @@ var (
 	// pattern is search pattern.
 	pattern string
 
+	// filter is filter pattern.
+	filter string
+
+	// non match filter pattern.
+	nonMatchFilter string
+
 	// ver is version information.
 	ver bool
 	// helpKey is key bind information.
@@ -156,6 +162,12 @@ func RunOviewer(args []string) error {
 	if pattern != "" {
 		ov.Search(pattern)
 	}
+	if filter != "" {
+		ov.Filter(filter, false)
+	}
+	if nonMatchFilter != "" {
+		ov.Filter(nonMatchFilter, true)
+	}
 
 	if err := ov.Run(); err != nil {
 		return err
@@ -331,7 +343,8 @@ func init() {
 	})
 
 	rootCmd.PersistentFlags().StringVarP(&pattern, "pattern", "", "", "search pattern")
-
+	rootCmd.PersistentFlags().StringVarP(&filter, "filter", "", "", "filter search pattern")
+	rootCmd.PersistentFlags().StringVarP(&nonMatchFilter, "non-match-filter", "", "", "filter non match search pattern")
 	rootCmd.PersistentFlags().BoolVarP(&oviewer.SkipExtract, "skip-extract", "", false, "skip extracting compressed files")
 
 	// Config.General
@@ -392,16 +405,16 @@ func init() {
 	rootCmd.PersistentFlags().IntP("section-header-num", "", 1, "number of header lines")
 	_ = viper.BindPFlag("general.SectionHeaderNum", rootCmd.PersistentFlags().Lookup("section-header-num"))
 
-	rootCmd.PersistentFlags().BoolP("follow-mode", "f", false, "follow mode")
+	rootCmd.PersistentFlags().BoolP("follow-mode", "f", false, "monitor file and display new content as it is written")
 	_ = viper.BindPFlag("general.FollowMode", rootCmd.PersistentFlags().Lookup("follow-mode"))
 
-	rootCmd.PersistentFlags().BoolP("follow-all", "A", false, "follow mode to switch to updated files")
+	rootCmd.PersistentFlags().BoolP("follow-all", "A", false, "follow multiple files and show the most recently updated one")
 	_ = viper.BindPFlag("general.FollowAll", rootCmd.PersistentFlags().Lookup("follow-all"))
 
 	rootCmd.PersistentFlags().BoolP("follow-section", "", false, "section-by-section follow mode")
 	_ = viper.BindPFlag("general.FollowSection", rootCmd.PersistentFlags().Lookup("follow-section"))
 
-	rootCmd.PersistentFlags().BoolP("follow-name", "", false, "file name follow mode")
+	rootCmd.PersistentFlags().BoolP("follow-name", "", false, "follow mode to monitor by file name")
 	_ = viper.BindPFlag("general.FollowName", rootCmd.PersistentFlags().Lookup("follow-name"))
 
 	rootCmd.PersistentFlags().IntP("watch", "T", 0, "watch mode interval(`seconds`)")
@@ -416,6 +429,9 @@ func init() {
 	rootCmd.PersistentFlags().StringP("hscroll-width", "", "10%", "width to scroll horizontally `[int|int%|.int]`")
 	_ = viper.BindPFlag("general.HScrollWidth", rootCmd.PersistentFlags().Lookup("hscroll-width"))
 
+	rootCmd.PersistentFlags().StringP("caption", "", "", "custom caption")
+	_ = viper.BindPFlag("general.Caption", rootCmd.PersistentFlags().Lookup("caption"))
+
 	// Config
 	rootCmd.PersistentFlags().BoolP("disable-mouse", "", false, "disable mouse support")
 	_ = viper.BindPFlag("DisableMouse", rootCmd.PersistentFlags().Lookup("disable-mouse"))
@@ -444,7 +460,7 @@ func init() {
 	rootCmd.PersistentFlags().BoolP("incsearch", "", true, "incremental search")
 	_ = viper.BindPFlag("Incsearch", rootCmd.PersistentFlags().Lookup("incsearch"))
 
-	rootCmd.PersistentFlags().StringP("view-mode", "", "", "view mode")
+	rootCmd.PersistentFlags().StringP("view-mode", "", "", "apply predefined settings for a specific mode")
 	_ = viper.BindPFlag("ViewMode", rootCmd.PersistentFlags().Lookup("view-mode"))
 
 	rootCmd.PersistentFlags().IntP("memory-limit", "", -1, "number of chunks to limit in memory")
@@ -499,6 +515,7 @@ func initConfig() {
 		}
 	}
 
+	viper.SetEnvPrefix("ov")
 	viper.AutomaticEnv() // read in environment variables that match
 
 	// If a config file is found, read it in.
