@@ -101,7 +101,7 @@ func (root *Root) toggleFollowSection() {
 
 // closeFile close the file.
 func (root *Root) closeFile() {
-	if root.screenMode != Docs {
+	if root.Doc.documentType == DocHelp || root.Doc.documentType == DocLog {
 		return
 	}
 
@@ -398,6 +398,9 @@ func (root *Root) setViewMode(modeName string) {
 	}
 
 	root.Doc.general = mergeGeneral(root.Doc.general, c)
+	if root.Doc.general.Caption != "" {
+		root.Doc.Caption = root.Doc.general.Caption
+	}
 	root.Doc.regexpCompile()
 	root.Doc.ClearCache()
 	root.ViewSync()
@@ -618,7 +621,7 @@ func (root *Root) TailSync() {
 // and adjusts to its original position.
 func (root *Root) tailSection() {
 	moved := root.Doc.topLN - root.Doc.lastSectionPosNum
-	root.lastSection()
+	root.Doc.moveLastSection()
 	if moved > 0 && (root.Doc.topLN+moved) < root.Doc.BufEndNum() {
 		root.Doc.moveLine(root.Doc.topLN + moved)
 	}
@@ -629,6 +632,10 @@ func (root *Root) tailSection() {
 func (root *Root) prepareStartX() {
 	root.scr.startX = 0
 	if root.Doc.LineNumMode {
+		if root.Doc.parent != nil {
+			root.scr.startX = len(fmt.Sprintf("%d", root.Doc.parent.BufEndNum())) + 1
+			return
+		}
 		root.scr.startX = len(fmt.Sprintf("%d", root.Doc.BufEndNum())) + 1
 	}
 }
@@ -663,7 +670,7 @@ func (root *Root) follow() {
 // followAll monitors and switches all document updates
 // in follow all mode.
 func (root *Root) followAll() {
-	if root.screenMode != Docs {
+	if root.Doc.documentType != DocNormal {
 		return
 	}
 
