@@ -15,16 +15,33 @@ import (
 	lru "github.com/hashicorp/golang-lru/v2"
 	"github.com/jwalton/gchalk"
 	"github.com/noborus/guesswidth"
+	"github.com/noborus/ov/biomap"
 )
 
+// document type.
+const (
+	DocNormal = iota
+	DocHelp
+	DocLog
+	DocFilter
+)
+
+type documentType int
+
 // The Document structure contains the values
 // for the logical screen.
 type Document struct {
+	// documentType is the type of document.
+	documentType documentType
 	// File is the os.File.
 	file *os.File
 
 	cache *lru.Cache[int, LineC]
 
+	// parent is the parent document.
+	parent     *Document
+	lineNumMap *biomap.Map[int, int]
+
 	ticker     *time.Ticker
 	tickerDone chan struct{}
 	// ctlCh is the channel for controlling the reader goroutine.
@@ -113,8 +130,10 @@ type Document struct {
 	seekable bool
 	// Is it possible to reopen.
 	reopenable bool
-	// startTopFlag
-	startTopFlag bool
+	// dupSectionHeader is true for lines that are duplicated in section header.
+	dupSectionHeader bool
+	// If nonMatch is true, non-matching lines are searched.
+	nonMatch bool
 }
 
 // store represents store management.
@@ -167,18 +186,19 @@ type LineC struct {
 // NewDocument returns Document.
 func NewDocument() (*Document, error) {
 	m := &Document{
-		tickerDone: make(chan struct{}),
+		documentType: DocNormal,
+		tickerDone:   make(chan struct{}),
 		general: general{
 			ColumnDelimiter: "",
 			TabWidth:        8,
 			MarkStyleWidth:  1,
 		},
-		ctlCh:        make(chan controlSpecifier),
-		memoryLimit:  100,
-		seekable:     true,
-		reopenable:   true,
-		store:        NewStore(),
-		startTopFlag: true,
+		ctlCh:            make(chan controlSpecifier),
+		memoryLimit:      100,
+		seekable:         true,
+		reopenable:       true,
+		store:            NewStore(),
+		dupSectionHeader: true,
 	}
 	if err := m.NewCache(); err != nil {
 		return nil, err
