@@ -26,7 +26,7 @@ func (root *Root) eventLoop(ctx context.Context, quitChan chan<- struct{}) {
 		ev := root.Screen.PollEvent()
 		switch ev := ev.(type) {
 		case *eventAppQuit:
-			if root.screenMode == Docs {
+			if root.Doc.documentType != DocHelp && root.Doc.documentType != DocLog {
 				close(quitChan)
 				return
 			}
@@ -44,6 +44,8 @@ func (root *Root) eventLoop(ctx context.Context, quitChan chan<- struct{}) {
 			root.addDocument(ev.m)
 		case *eventCloseDocument:
 			root.closeDocument()
+		case *eventCloseAllFilter:
+			root.closeAllFilter()
 		case *eventCopySelect:
 			root.copyToClipboard(ctx)
 		case *eventPaste:
@@ -51,11 +53,9 @@ func (root *Root) eventLoop(ctx context.Context, quitChan chan<- struct{}) {
 		case *eventViewMode:
 			root.setViewMode(ev.value)
 		case *eventInputSearch:
-			root.firstSearch(ctx)
+			root.firstSearch(ctx, ev.searchType)
 		case *eventNextSearch:
 			root.nextSearch(ctx, ev.str)
-		case *eventInputBackSearch:
-			root.firstBackSearch(ctx)
 		case *eventNextBackSearch:
 			root.nextBackSearch(ctx, ev.str)
 		case *eventSearchMove:
@@ -273,7 +273,7 @@ type eventCloseDocument struct {
 }
 
 // CloseDocument fires the eventCloseDocument event.
-func (root *Root) CloseDocument(m *Document) {
+func (root *Root) CloseDocument(_ *Document) {
 	root.sendCloseDocument()
 }
 
@@ -283,6 +283,20 @@ func (root *Root) sendCloseDocument() {
 	root.postEvent(ev)
 }
 
+type eventCloseAllFilter struct {
+	tcell.EventTime
+}
+
+func (root *Root) CloseAllFilter() {
+	root.sendCloseAllFilter()
+}
+
+func (root *Root) sendCloseAllFilter() {
+	ev := &eventCloseAllFilter{}
+	ev.SetEventNow()
+	root.postEvent(ev)
+}
+
 // eventReload represents a reload event.
 type eventReload struct {
 	m *Document
