@@ -5,18 +5,10 @@ import "github.com/gdamore/tcell/v2"
 // setGoLineMode sets the inputMode to Goline.
 func (root *Root) setGoLineMode() {
 	input := root.input
-	input.value = ""
-	input.cursorX = 0
+	input.reset()
 	input.Event = newGotoEvent(input.GoCandidate)
 }
 
-// gotoCandidate returns the candidate to set to default.
-func gotoCandidate() *candidate {
-	return &candidate{
-		list: []string{},
-	}
-}
-
 // eventGoto represents the goto input mode.
 type eventGoto struct {
 	tcell.EventTime
@@ -30,12 +22,12 @@ func newGotoEvent(clist *candidate) *eventGoto {
 }
 
 // Mode returns InputMode.
-func (e *eventGoto) Mode() InputMode {
+func (*eventGoto) Mode() InputMode {
 	return Goline
 }
 
 // Prompt returns the prompt string in the input field.
-func (e *eventGoto) Prompt() string {
+func (*eventGoto) Prompt() string {
 	return "Goto line:"
 }
 
@@ -48,11 +40,11 @@ func (e *eventGoto) Confirm(str string) tcell.Event {
 }
 
 // Up returns strings when the up key is pressed during input.
-func (e *eventGoto) Up(str string) string {
+func (e *eventGoto) Up(_ string) string {
 	return e.clist.up()
 }
 
 // Down returns strings when the down key is pressed during input.
-func (e *eventGoto) Down(str string) string {
+func (e *eventGoto) Down(_ string) string {
 	return e.clist.down()
 }
