@@ -5,18 +5,10 @@ import "github.com/gdamore/tcell/v2"
 // setWriteBAMode sets the inputMode to WriteBA.
 func (root *Root) setWriteBAMode() {
 	input := root.input
-	input.value = ""
-	input.cursorX = 0
+	input.reset()
 	input.Event = newWriteBAEvent(input.WriteBACandidate)
 }
 
-// baCandidate returns the candidate to set to default.
-func baCandidate() *candidate {
-	return &candidate{
-		list: []string{},
-	}
-}
-
 // eventWriteBA represents the writeBA input mode.
 type eventWriteBA struct {
 	tcell.EventTime
@@ -30,12 +22,12 @@ func newWriteBAEvent(clist *candidate) *eventWriteBA {
 }
 
 // Mode returns InputMode.
-func (e *eventWriteBA) Mode() InputMode {
+func (*eventWriteBA) Mode() InputMode {
 	return WriteBA
 }
 
 // Prompt returns the prompt string in the input field.
-func (e *eventWriteBA) Prompt() string {
+func (*eventWriteBA) Prompt() string {
 	return "WriteAndQuit Before:After:"
 }
 
@@ -48,11 +40,11 @@ func (e *eventWriteBA) Confirm(str string) tcell.Event {
 }
 
 // Up returns strings when the up key is pressed during input.
-func (e *eventWriteBA) Up(str string) string {
+func (e *eventWriteBA) Up(_ string) string {
 	return e.clist.up()
 }
 
 // Down returns strings when the down key is pressed during input.
-func (e *eventWriteBA) Down(str string) string {
+func (e *eventWriteBA) Down(_ string) string {
 	return e.clist.down()
 }
