@@ -19,19 +19,6 @@ import (
 	"golang.org/x/sync/errgroup"
 )
 
-//  1. search key event(/)		back search key event(?)
-//  2. actionSearch				setBackSearchMode			(key event)
-//  3. root.setSearchMode()		root.setBackSearchMode()
-//  4. input...confirm			input...confirm
-//  5. *eventInputSearch		*eventInputBackSearch		(event)
-//  6. root.firstSearch()		root.firstBackSearch()
-//
-//  7. next search key event(n)	next backsearch key event(N)
-//  8. actionNextSearch			actionNextBackSearch		(key event)
-//  9. root.setNextSearch()		root.setNextBackSearch()
-// 10. *eventNextSearch			*eventNextBackSearch		(event)
-// 11. root.nextSearch()		root.nextBackSearch()
-
 // Searcher interface provides a match method that determines
 // if the search word matches the argument string.
 type Searcher interface {
@@ -224,14 +211,14 @@ func condRegexpCompile(in string) *regexp.Regexp {
 }
 
 // searchPosition returns the position where the search in the argument line matched.
-func (root *Root) searchPosition(lN int, str string) [][]int {
+func (root *Root) searchPosition(str string) [][]int {
 	return root.searcher.FindAll(str)
 }
 
 // searchXPos returns the x position of the first match.
-func (root *Root) searchXPos(lN int) int {
-	line, _ := root.Doc.getLineC(lN, root.Doc.TabWidth)
-	indexes := root.searchPosition(lN, line.str)
+func (root *Root) searchXPos(lineNum int) int {
+	line, _ := root.Doc.getLineC(lineNum, root.Doc.TabWidth)
+	indexes := root.searchPosition(line.str)
 	if len(indexes) == 0 {
 		return 0
 	}
@@ -247,20 +234,6 @@ func searchPositionReg(s string, re *regexp.Regexp) [][]int {
 	return re.FindAllStringIndex(s, -1)
 }
 
-// searchPositionStr returns an array of the beginning and end of the string
-// that matched the string search.
-func searchPositionStr(caseSensitive bool, s string, substr string) [][]int {
-	if substr == "" {
-		return nil
-	}
-
-	if !caseSensitive {
-		s = strings.ToLower(s)
-		substr = strings.ToLower(substr)
-	}
-	return allStringIndex(s, substr)
-}
-
 // setSearcher is a wrapper for NewSearcher and returns a Searcher interface.
 // Returns nil if there is no search term.
 func (root *Root) setSearcher(word string, caseSensitive bool) Searcher {
@@ -285,7 +258,7 @@ func (root *Root) setSearcher(word string, caseSensitive bool) Searcher {
 }
 
 // searchMove searches forward/backward and moves to the nearest matching line.
-func (root *Root) searchMove(ctx context.Context, forward bool, lN int, searcher Searcher) {
+func (root *Root) searchMove(ctx context.Context, forward bool, lineNum int, searcher Searcher) {
 	if searcher == nil {
 		if root.Doc.jumpTargetSection {
 			root.Doc.jumpTargetNum = 0
@@ -303,7 +276,7 @@ func (root *Root) searchMove(ctx context.Context, forward bool, lN int, searcher
 	})
 
 	eg.Go(func() error {
-		n, err := root.Doc.searchLine(ctx, searcher, forward, lN)
+		n, err := root.Doc.searchLine(ctx, searcher, forward, lineNum)
 		root.sendSearchQuit()
 		if err != nil {
 			return fmt.Errorf("search:%w:%v", err, word)
@@ -320,15 +293,15 @@ func (root *Root) searchMove(ctx context.Context, forward bool, lN int, searcher
 }
 
 // searchLine is a forward/backward search wrap function
-func (m *Document) searchLine(ctx context.Context, searcher Searcher, forward bool, lN int) (int, error) {
+func (m *Document) searchLine(ctx context.Context, searcher Searcher, forward bool, lineNum int) (int, error) {
 	if forward {
-		return m.SearchLine(ctx, searcher, lN)
+		return m.SearchLine(ctx, searcher, lineNum)
 	}
-	return m.BackSearchLine(ctx, searcher, lN)
+	return m.BackSearchLine(ctx, searcher, lineNum)
 }
 
 // Search searches for the search term and moves to the nearest matching line.
-func (m *Document) Search(ctx context.Context, searcher Searcher, chunkNum int, line int) (int, error) {
+func (m *Document) Search(ctx context.Context, searcher Searcher, chunkNum int, lineNum int) (int, error) {
 	if !m.seekable {
 		if chunkNum != 0 && m.store.lastChunkNum() <= chunkNum {
 			m.requestLoad(chunkNum)
@@ -337,12 +310,20 @@ func (m *Document) Search(ctx context.Context, searcher Searcher, chunkNum int,
 		if m.store.lastChunkNum() < chunkNum {
 			return 0, ErrOutOfChunk
 		}
-		if !m.store.isLoadedChunk(chunkNum, m.seekable) && !m.storageSearch(ctx, searcher, chunkNum, line) {
+		if !m.store.isLoadedChunk(chunkNum, m.seekable) && !m.storageSearch(searcher, chunkNum) {
 			return 0, ErrNotFound
 		}
 	}
 
-	for n := line; n < ChunkSize; n++ {
+	if m.nonMatch {
+		return m.SearchChunkNonMatch(ctx, searcher, chunkNum, lineNum)
+	}
+	return m.SearchChunk(ctx, searcher, chunkNum, lineNum)
+}
+
+// SearchChunk searches forward from the specified line.
+func (m *Document) SearchChunk(ctx context.Context, searcher Searcher, chunkNum int, lineNum int) (int, error) {
+	for n := lineNum; n < ChunkSize; n++ {
 		buf, err := m.store.GetChunkLine(chunkNum, n)
 		if err != nil {
 			return n, fmt.Errorf("%w: %d:%d", err, chunkNum, n)
@@ -359,12 +340,38 @@ func (m *Document) Search(ctx context.Context, searcher Searcher, chunkNum int,
 	return 0, ErrNotFound
 }
 
+// SearchChunkNonMatch returns unmatched line number.
+func (m *Document) SearchChunkNonMatch(ctx context.Context, searcher Searcher, chunkNum int, lineNum int) (int, error) {
+	for n := lineNum; n < ChunkSize; n++ {
+		buf, err := m.store.GetChunkLine(chunkNum, n)
+		if err != nil {
+			return n, fmt.Errorf("%w: %d:%d", err, chunkNum, n)
+		}
+		if !searcher.Match(buf) {
+			return n, nil
+		}
+		select {
+		case <-ctx.Done():
+			return 0, ErrCancel
+		default:
+		}
+	}
+	return 0, ErrNotFound
+}
+
 // BackSearch searches backward from the specified line.
 func (m *Document) BackSearch(ctx context.Context, searcher Searcher, chunkNum int, line int) (int, error) {
-	if !m.store.isLoadedChunk(chunkNum, m.seekable) && !m.storageSearch(ctx, searcher, chunkNum, line) {
+	if !m.store.isLoadedChunk(chunkNum, m.seekable) && !m.storageSearch(searcher, chunkNum) {
 		return 0, ErrNotFound
 	}
+	if m.nonMatch {
+		return m.BackSearchChunkNonMatch(ctx, searcher, chunkNum, line)
+	}
+	return m.BackSearchChunk(ctx, searcher, chunkNum, line)
+}
 
+// BackSearchChunk searches backward from the specified line.
+func (m *Document) BackSearchChunk(ctx context.Context, searcher Searcher, chunkNum int, line int) (int, error) {
 	for n := line; n >= 0; n-- {
 		buf, err := m.store.GetChunkLine(chunkNum, n)
 		if err != nil {
@@ -382,8 +389,27 @@ func (m *Document) BackSearch(ctx context.Context, searcher Searcher, chunkNum i
 	return 0, ErrNotFound
 }
 
+// BackSearchChunkNonMatch returns unmatched line number.
+func (m *Document) BackSearchChunkNonMatch(ctx context.Context, searcher Searcher, chunkNum int, line int) (int, error) {
+	for n := line; n >= 0; n-- {
+		buf, err := m.store.GetChunkLine(chunkNum, n)
+		if err != nil {
+			return n, fmt.Errorf("%w: %d:%d", err, chunkNum, n)
+		}
+		if !searcher.Match(buf) {
+			return n, nil
+		}
+		select {
+		case <-ctx.Done():
+			return 0, ErrCancel
+		default:
+		}
+	}
+	return 0, ErrNotFound
+}
+
 // storageSearch searches for line not in memory(storage).
-func (m *Document) storageSearch(ctx context.Context, searcher Searcher, chunkNum int, line int) bool {
+func (m *Document) storageSearch(searcher Searcher, chunkNum int) bool {
 	if !m.store.isLoadedChunk(chunkNum, m.seekable) && atomic.LoadInt32(&m.closed) == 0 {
 		if m.requestSearch(chunkNum, searcher) {
 			return true
@@ -393,9 +419,9 @@ func (m *Document) storageSearch(ctx context.Context, searcher Searcher, chunkNu
 }
 
 // SearchLine searches the document and returns the matching line number.
-func (m *Document) SearchLine(ctx context.Context, searcher Searcher, lN int) (int, error) {
-	lN = max(lN, m.BufStartNum())
-	startChunk, sn := chunkLineNum(lN)
+func (m *Document) SearchLine(ctx context.Context, searcher Searcher, lineNum int) (int, error) {
+	lineNum = max(lineNum, m.BufStartNum())
+	startChunk, sn := chunkLineNum(lineNum)
 
 	for cn := startChunk; ; cn++ {
 		n, err := m.Search(ctx, searcher, cn, sn)
@@ -410,18 +436,19 @@ func (m *Document) SearchLine(ctx context.Context, searcher Searcher, lN int) (i
 
 		// lastChunkNum may be updated by Search.
 		if cn >= m.store.lastChunkNum() {
+			lineNum = cn*ChunkSize + n
 			break
 		}
 		sn = 0
 	}
 
-	return 0, ErrNotFound
+	return lineNum, ErrNotFound
 }
 
 // BackSearchLine does a backward search on the document and returns a matching line number.
-func (m *Document) BackSearchLine(ctx context.Context, searcher Searcher, lN int) (int, error) {
-	lN = min(lN, m.BufEndNum()-1)
-	startChunk, sn := chunkLineNum(lN)
+func (m *Document) BackSearchLine(ctx context.Context, searcher Searcher, lineNum int) (int, error) {
+	lineNum = min(lineNum, m.BufEndNum()-1)
+	startChunk, sn := chunkLineNum(lineNum)
 	minChunk, _ := chunkLineNum(m.BufStartNum())
 	for cn := startChunk; cn >= minChunk; cn-- {
 		n, err := m.BackSearch(ctx, searcher, cn, sn)
@@ -440,7 +467,7 @@ func (m *Document) BackSearchLine(ctx context.Context, searcher Searcher, lN int
 
 // cancelWait waits for key to cancel.
 func (root *Root) cancelWait(cancel context.CancelFunc) error {
-	cancelApp := func(ev *tcell.EventKey) *tcell.EventKey {
+	cancelApp := func(_ *tcell.EventKey) *tcell.EventKey {
 		cancel()
 		root.setMessage("cancel")
 		return nil
@@ -494,10 +521,10 @@ type eventSearchMove struct {
 	value int
 }
 
-func (root *Root) sendSearchMove(lN int) {
+func (root *Root) sendSearchMove(lineNum int) {
 	ev := &eventSearchMove{}
 	ev.SetEventNow()
-	ev.value = lN
+	ev.value = lineNum
 	root.postEvent(ev)
 }
 
@@ -516,7 +543,7 @@ func (root *Root) incrementalSearch(ctx context.Context) {
 }
 
 // incSearch implements incremental forward/back search.
-func (root *Root) incSearch(ctx context.Context, forward bool, lN int) {
+func (root *Root) incSearch(ctx context.Context, forward bool, lineNum int) {
 	root.Doc.topLN = root.returnStartPosition()
 
 	searcher := root.setSearcher(root.input.value, root.Config.CaseSensitive)
@@ -526,7 +553,7 @@ func (root *Root) incSearch(ctx context.Context, forward bool, lN int) {
 
 	ctx = root.cancelRestart(ctx)
 	go func() {
-		n, err := root.Doc.searchLine(ctx, searcher, forward, lN)
+		n, err := root.Doc.searchLine(ctx, searcher, forward, lineNum)
 		if err != nil {
 			root.debugMessage(fmt.Sprintf("incSearch: %s", err))
 			return
@@ -569,7 +596,21 @@ func (root *Root) startSearchLN() int {
 }
 
 // firstSearch performs the first search immediately after the input.
-func (root *Root) firstSearch(ctx context.Context) {
+func (root *Root) firstSearch(ctx context.Context, t searchType) {
+	switch t {
+	case forward:
+		root.firstForwardSearch(ctx)
+		return
+	case backward:
+		root.firstBackSearch(ctx)
+		return
+	case filter:
+		root.filter(ctx)
+	}
+}
+
+// firstForwardSearch performs the first forward search immediately after the input.
+func (root *Root) firstForwardSearch(ctx context.Context) {
 	searcher := root.setSearcher(root.input.value, root.Config.CaseSensitive)
 	root.searchMove(ctx, true, root.startSearchLN(), searcher)
 }
